==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/TaintFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface TaintFluent<A extends TaintFluent<A>> extends Fluent<A> {


    public String getEffect();
    public A withEffect(String effect);
    public Boolean hasEffect();
    public A withNewEffect(StringBuilder arg1);
    public A withNewEffect(int[] arg1,int arg2,int arg3);
    public A withNewEffect(char[] arg1);
    public A withNewEffect(StringBuffer arg1);
    public A withNewEffect(byte[] arg1,int arg2);
    public A withNewEffect(byte[] arg1);
    public A withNewEffect(char[] arg1,int arg2,int arg3);
    public A withNewEffect(byte[] arg1,int arg2,int arg3);
    public A withNewEffect(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewEffect(String arg1);
    public String getKey();
    public A withKey(String key);
    public Boolean hasKey();
    public A withNewKey(StringBuilder arg1);
    public A withNewKey(int[] arg1,int arg2,int arg3);
    public A withNewKey(char[] arg1);
    public A withNewKey(StringBuffer arg1);
    public A withNewKey(byte[] arg1,int arg2);
    public A withNewKey(byte[] arg1);
    public A withNewKey(char[] arg1,int arg2,int arg3);
    public A withNewKey(byte[] arg1,int arg2,int arg3);
    public A withNewKey(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKey(String arg1);
    public String getTimeAdded();
    public A withTimeAdded(String timeAdded);
    public Boolean hasTimeAdded();
    public A withNewTimeAdded(StringBuilder arg1);
    public A withNewTimeAdded(int[] arg1,int arg2,int arg3);
    public A withNewTimeAdded(char[] arg1);
    public A withNewTimeAdded(StringBuffer arg1);
    public A withNewTimeAdded(byte[] arg1,int arg2);
    public A withNewTimeAdded(byte[] arg1);
    public A withNewTimeAdded(char[] arg1,int arg2,int arg3);
    public A withNewTimeAdded(byte[] arg1,int arg2,int arg3);
    public A withNewTimeAdded(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTimeAdded(String arg1);
    public String getValue();
    public A withValue(String value);
    public Boolean hasValue();
    public A withNewValue(StringBuilder arg1);
    public A withNewValue(int[] arg1,int arg2,int arg3);
    public A withNewValue(char[] arg1);
    public A withNewValue(StringBuffer arg1);
    public A withNewValue(byte[] arg1,int arg2);
    public A withNewValue(byte[] arg1);
    public A withNewValue(char[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewValue(String arg1);
}

==> kubernetes-model-core-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/TaintFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface TaintFluent<A extends TaintFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getEffect();
    public A withEffect(String effect);
    public Boolean hasEffect();
    public A withNewEffect(StringBuilder arg1);
    public A withNewEffect(int[] arg1,int arg2,int arg3);
    public A withNewEffect(char[] arg1);
    public A withNewEffect(StringBuffer arg1);
    public A withNewEffect(byte[] arg1,int arg2);
    public A withNewEffect(byte[] arg1);
    public A withNewEffect(char[] arg1,int arg2,int arg3);
    public A withNewEffect(byte[] arg1,int arg2,int arg3);
    public A withNewEffect(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewEffect(String arg1);
    public String getKey();
    public A withKey(String key);
    public Boolean hasKey();
    public A withNewKey(StringBuilder arg1);
    public A withNewKey(int[] arg1,int arg2,int arg3);
    public A withNewKey(char[] arg1);
    public A withNewKey(StringBuffer arg1);
    public A withNewKey(byte[] arg1,int arg2);
    public A withNewKey(byte[] arg1);
    public A withNewKey(char[] arg1,int arg2,int arg3);
    public A withNewKey(byte[] arg1,int arg2,int arg3);
    public A withNewKey(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKey(String arg1);
    public String getTimeAdded();
    public A withTimeAdded(String timeAdded);
    public Boolean hasTimeAdded();
    public A withNewTimeAdded(StringBuilder arg1);
    public A withNewTimeAdded(int[] arg1,int arg2,int arg3);
    public A withNewTimeAdded(char[] arg1);
    public A withNewTimeAdded(StringBuffer arg1);
    public A withNewTimeAdded(byte[] arg1,int arg2);
    public A withNewTimeAdded(byte[] arg1);
    public A withNewTimeAdded(char[] arg1,int arg2,int arg3);
    public A withNewTimeAdded(byte[] arg1,int arg2,int arg3);
    public A withNewTimeAdded(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTimeAdded(String arg1);
    public String getValue();
    public A withValue(String value);
    public Boolean hasValue();
    public A withNewValue(StringBuilder arg1);
    public A withNewValue(int[] arg1,int arg2,int arg3);
    public A withNewValue(char[] arg1);
    public A withNewValue(StringBuffer arg1);
    public A withNewValue(byte[] arg1,int arg2);
    public A withNewValue(byte[] arg1);
    public A withNewValue(char[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3);
    public A withNewValue(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewValue(String arg1);
}
